package cn.iocoder.yudao.module.shop.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import cn.iocoder.yudao.module.shop.entity.ShopCouponTemplate;

import java.util.List;

/**
 * 优惠券模板Service接口
 *
 * @author ruoyi
 * @date 2023-08-29
 */
public interface IShopCouponTemplateService  extends IService<ShopCouponTemplate>
{
    /**
     * 查询优惠券模板
     *
     * @param id 优惠券模板主键
     * @return 优惠券模板
     */
    public ShopCouponTemplate selectShopCouponTemplateById(Long id);

    /**
     * 查询优惠券模板列表
     *
     * @param shopCouponTemplate 优惠券模板
     * @return 优惠券模板集合
     */
    public IPage<ShopCouponTemplate> selectShopCouponTemplateList(Page<ShopCouponTemplate> page,ShopCouponTemplate shopCouponTemplate);

    /**
     * 新增优惠券模板
     *
     * @param shopCouponTemplate 优惠券模板
     * @return 结果
     */
    public int insertShopCouponTemplate(ShopCouponTemplate shopCouponTemplate);

    /**
     * 修改优惠券模板
     *
     * @param shopCouponTemplate 优惠券模板
     * @return 结果
     */
    public int updateShopCouponTemplate(ShopCouponTemplate shopCouponTemplate);

    /**
     * 批量删除优惠券模板
     *
     * @param ids 需要删除的优惠券模板主键集合
     * @return 结果
     */
    public int deleteShopCouponTemplateByIds(Long[] ids);

    /**
     * 删除优惠券模板信息
     *
     * @param id 优惠券模板主键
     * @return 结果
     */
    public int deleteShopCouponTemplateById(Long id);
    IPage<ShopCouponTemplate> listCoupon(Page<ShopCouponTemplate> page,Long partnerId, String searchValue);
}
